@@ -2,8 +2,7 @@
  *
  * This file is part of Mapnik (c++ mapping toolkit)
  *
- * Copyright (C) 2006 Artem Pavlenko
- * Copyright (C) 2006 10East Corp.
+ * Copyright (C) 2011 Artem Pavlenko
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,17 +19,18 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *****************************************************************************/
-//$Id$
 
 #ifndef MAPNIK_SHIELD_SYMBOLIZER_HPP
 #define MAPNIK_SHIELD_SYMBOLIZER_HPP
 
 // mapnik
+#include <mapnik/config.hpp>
+#include <mapnik/color.hpp>
 #include <mapnik/symbolizer.hpp>
+#include <mapnik/expression.hpp>
 #include <mapnik/text_symbolizer.hpp>
 
 // boost
-#include <boost/shared_ptr.hpp>
 #include <boost/tuple/tuple.hpp>
 
 namespace mapnik
@@ -38,28 +38,28 @@ namespace mapnik
 struct MAPNIK_DECL shield_symbolizer : public text_symbolizer,
                                        public symbolizer_with_image
 {
+    // Note - we do not use boost::make_shared below as VC2008 and VC2010 are
+    // not able to compile make_shared used within a constructor
+    shield_symbolizer(text_placements_ptr placements = text_placements_ptr(new text_placements_dummy));
     shield_symbolizer(expression_ptr name,
                       std::string const& face_name,
-                      unsigned size,
+                      float size,
                       color const& fill,
                       path_expression_ptr file);
     shield_symbolizer(expression_ptr name,
-                      unsigned size,
+                      float size,
                       color const& fill,
                       path_expression_ptr file);
-    
+
     bool get_unlock_image() const;              // image is not locked to the text placement
     void set_unlock_image(bool unlock_image);
-    bool get_no_text() const;                   // do no render text
-    void set_no_text(bool unlock_image);
-    void set_shield_displacement(double shield_dx,double shield_dy);
-    boost::tuple<double,double> const& get_shield_displacement() const;
-    
+    void set_shield_displacement(double shield_dx, double shield_dy);
+    position const& get_shield_displacement() const;
+
 private:
     bool unlock_image_;
-    bool no_text_;
-    boost::tuple<double,double> shield_displacement_;
+    position shield_displacement_;
 };
 }
 
-#endif // SHIELD_SYMBOLIZER_HPP
+#endif // MAPNIK_SHIELD_SYMBOLIZER_HPP
